#[repr(C)]pub struct AttachmentSampleCountInfoAMD {
pub s_type: StructureType,
pub next: *const c_void,
pub color_attachment_count: u32,
pub color_attachment_samples: *const SampleCountFlags,
pub depth_stencil_attachment_samples: SampleCountFlags,
}Expand description
Fields
s_type: StructureTypenext: *const c_voidcolor_attachment_count: u32color_attachment_samples: *const SampleCountFlagsdepth_stencil_attachment_samples: SampleCountFlagsTrait Implementations
Sourceimpl Cast for AttachmentSampleCountInfoAMD
impl Cast for AttachmentSampleCountInfoAMD
Sourcetype Target = AttachmentSampleCountInfoAMD
type Target = AttachmentSampleCountInfoAMD
The other type this type can be used interchangeably with in FFI.
Sourceimpl Clone for AttachmentSampleCountInfoAMD
impl Clone for AttachmentSampleCountInfoAMD
Sourcefn clone(&self) -> AttachmentSampleCountInfoAMD
fn clone(&self) -> AttachmentSampleCountInfoAMD
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AttachmentSampleCountInfoAMD
impl Debug for AttachmentSampleCountInfoAMD
Sourceimpl Default for AttachmentSampleCountInfoAMD
impl Default for AttachmentSampleCountInfoAMD
Sourcefn default() -> AttachmentSampleCountInfoAMD
fn default() -> AttachmentSampleCountInfoAMD
Returns the “default value” for a type. Read more
Sourceimpl<'b> HasBuilder<'b> for AttachmentSampleCountInfoAMD
impl<'b> HasBuilder<'b> for AttachmentSampleCountInfoAMD
Sourceimpl Hash for AttachmentSampleCountInfoAMD
impl Hash for AttachmentSampleCountInfoAMD
Sourceimpl PartialEq for AttachmentSampleCountInfoAMD
impl PartialEq for AttachmentSampleCountInfoAMD
Sourcefn eq(&self, other: &AttachmentSampleCountInfoAMD) -> bool
fn eq(&self, other: &AttachmentSampleCountInfoAMD) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for AttachmentSampleCountInfoAMD
impl Eq for AttachmentSampleCountInfoAMD
impl ExtendsCommandBufferInheritanceInfo for AttachmentSampleCountInfoAMD
impl ExtendsGraphicsPipelineCreateInfo for AttachmentSampleCountInfoAMD
impl Send for AttachmentSampleCountInfoAMD
impl StructuralPartialEq for AttachmentSampleCountInfoAMD
impl Sync for AttachmentSampleCountInfoAMD