pub struct BufferUsageFlags { /* private fields */ }Expand description
Implementations
Sourceimpl BufferUsageFlags
impl BufferUsageFlags
pub const TRANSFER_SRC: BufferUsageFlags
pub const TRANSFER_DST: BufferUsageFlags
pub const UNIFORM_TEXEL_BUFFER: BufferUsageFlags
pub const STORAGE_TEXEL_BUFFER: BufferUsageFlags
pub const UNIFORM_BUFFER: BufferUsageFlags
pub const STORAGE_BUFFER: BufferUsageFlags
pub const INDEX_BUFFER: BufferUsageFlags
pub const VERTEX_BUFFER: BufferUsageFlags
pub const INDIRECT_BUFFER: BufferUsageFlags
pub const CONDITIONAL_RENDERING_EXT: BufferUsageFlags
pub const SHADER_BINDING_TABLE_KHR: BufferUsageFlags
pub const TRANSFORM_FEEDBACK_BUFFER_EXT: BufferUsageFlags
pub const TRANSFORM_FEEDBACK_COUNTER_BUFFER_EXT: BufferUsageFlags
pub const VIDEO_DECODE_SRC_KHR: BufferUsageFlags
pub const VIDEO_DECODE_DST_KHR: BufferUsageFlags
pub const VIDEO_ENCODE_DST_KHR: BufferUsageFlags
pub const VIDEO_ENCODE_SRC_KHR: BufferUsageFlags
pub const SHADER_DEVICE_ADDRESS: BufferUsageFlags
pub const ACCELERATION_STRUCTURE_BUILD_INPUT_READ_ONLY_KHR: BufferUsageFlags
pub const ACCELERATION_STRUCTURE_STORAGE_KHR: BufferUsageFlags
pub const SAMPLER_DESCRIPTOR_BUFFER_EXT: BufferUsageFlags
pub const RESOURCE_DESCRIPTOR_BUFFER_EXT: BufferUsageFlags
pub const MICROMAP_BUILD_INPUT_READ_ONLY_EXT: BufferUsageFlags
pub const MICROMAP_STORAGE_EXT: BufferUsageFlags
pub const EXECUTION_GRAPH_SCRATCH_AMDX: BufferUsageFlags
pub const PUSH_DESCRIPTORS_DESCRIPTOR_BUFFER_EXT: BufferUsageFlags
pub const TILE_MEMORY_QCOM: BufferUsageFlags
pub const DESCRIPTOR_HEAP_EXT: BufferUsageFlags
Sourcepub const fn empty() -> BufferUsageFlags
pub const fn empty() -> BufferUsageFlags
Returns an empty set of flags.
Sourcepub const fn all() -> BufferUsageFlags
pub const fn all() -> BufferUsageFlags
Returns the set containing all flags.
Sourcepub const fn from_bits(bits: u32) -> Option<BufferUsageFlags>
pub const fn from_bits(bits: u32) -> Option<BufferUsageFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: u32) -> BufferUsageFlags
pub const fn from_bits_truncate(bits: u32) -> BufferUsageFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> BufferUsageFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> BufferUsageFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
Sourcepub const fn intersects(&self, other: BufferUsageFlags) -> bool
pub const fn intersects(&self, other: BufferUsageFlags) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: BufferUsageFlags) -> bool
pub const fn contains(&self, other: BufferUsageFlags) -> bool
Returns true if all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: BufferUsageFlags)
pub fn insert(&mut self, other: BufferUsageFlags)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: BufferUsageFlags)
pub fn remove(&mut self, other: BufferUsageFlags)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: BufferUsageFlags)
pub fn toggle(&mut self, other: BufferUsageFlags)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: BufferUsageFlags, value: bool)
pub fn set(&mut self, other: BufferUsageFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.
Sourcepub const fn intersection(self, other: BufferUsageFlags) -> BufferUsageFlags
pub const fn intersection(self, other: BufferUsageFlags) -> BufferUsageFlags
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
Sourcepub const fn union(self, other: BufferUsageFlags) -> BufferUsageFlags
pub const fn union(self, other: BufferUsageFlags) -> BufferUsageFlags
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
Sourcepub const fn difference(self, other: BufferUsageFlags) -> BufferUsageFlags
pub const fn difference(self, other: BufferUsageFlags) -> BufferUsageFlags
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
Sourcepub const fn symmetric_difference(
self,
other: BufferUsageFlags,
) -> BufferUsageFlags
pub const fn symmetric_difference( self, other: BufferUsageFlags, ) -> BufferUsageFlags
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
Sourcepub const fn complement(self) -> BufferUsageFlags
pub const fn complement(self) -> BufferUsageFlags
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.