#[repr(C)]pub struct CommandBufferInheritanceRenderPassTransformInfoQCOM {
pub s_type: StructureType,
pub next: *const c_void,
pub transform: SurfaceTransformFlagsKHR,
pub render_area: Rect2D,
}Expand description
Fields
s_type: StructureTypenext: *const c_voidtransform: SurfaceTransformFlagsKHRrender_area: Rect2DTrait Implementations
Sourceimpl Cast for CommandBufferInheritanceRenderPassTransformInfoQCOM
impl Cast for CommandBufferInheritanceRenderPassTransformInfoQCOM
Sourcetype Target = CommandBufferInheritanceRenderPassTransformInfoQCOM
type Target = CommandBufferInheritanceRenderPassTransformInfoQCOM
The other type this type can be used interchangeably with in FFI.
Sourceimpl Clone for CommandBufferInheritanceRenderPassTransformInfoQCOM
impl Clone for CommandBufferInheritanceRenderPassTransformInfoQCOM
Sourcefn clone(&self) -> CommandBufferInheritanceRenderPassTransformInfoQCOM
fn clone(&self) -> CommandBufferInheritanceRenderPassTransformInfoQCOM
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for CommandBufferInheritanceRenderPassTransformInfoQCOM
impl Default for CommandBufferInheritanceRenderPassTransformInfoQCOM
Sourcefn default() -> CommandBufferInheritanceRenderPassTransformInfoQCOM
fn default() -> CommandBufferInheritanceRenderPassTransformInfoQCOM
Returns the “default value” for a type. Read more
Sourceimpl HasBuilder<'static> for CommandBufferInheritanceRenderPassTransformInfoQCOM
impl HasBuilder<'static> for CommandBufferInheritanceRenderPassTransformInfoQCOM
Sourceimpl InputChainStruct for CommandBufferInheritanceRenderPassTransformInfoQCOM
impl InputChainStruct for CommandBufferInheritanceRenderPassTransformInfoQCOM
Sourceconst TYPE: StructureType = StructureType::COMMAND_BUFFER_INHERITANCE_RENDER_PASS_TRANSFORM_INFO_QCOM
const TYPE: StructureType = StructureType::COMMAND_BUFFER_INHERITANCE_RENDER_PASS_TRANSFORM_INFO_QCOM
The structure type for this struct type.
Sourcefn s_type(&self) -> StructureType
fn s_type(&self) -> StructureType
The structure type for this struct.
Sourceimpl PartialEq for CommandBufferInheritanceRenderPassTransformInfoQCOM
impl PartialEq for CommandBufferInheritanceRenderPassTransformInfoQCOM
Sourcefn eq(
&self,
other: &CommandBufferInheritanceRenderPassTransformInfoQCOM,
) -> bool
fn eq( &self, other: &CommandBufferInheritanceRenderPassTransformInfoQCOM, ) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for CommandBufferInheritanceRenderPassTransformInfoQCOM
impl Eq for CommandBufferInheritanceRenderPassTransformInfoQCOM
impl ExtendsCommandBufferInheritanceInfo for CommandBufferInheritanceRenderPassTransformInfoQCOM
impl Send for CommandBufferInheritanceRenderPassTransformInfoQCOM
impl StructuralPartialEq for CommandBufferInheritanceRenderPassTransformInfoQCOM
impl Sync for CommandBufferInheritanceRenderPassTransformInfoQCOM