#[repr(C)]pub struct DescriptorSetLayoutBinding {
pub binding: u32,
pub descriptor_type: DescriptorType,
pub descriptor_count: u32,
pub stage_flags: ShaderStageFlags,
pub immutable_samplers: *const Sampler,
}Expand description
Fields
binding: u32descriptor_type: DescriptorTypedescriptor_count: u32stage_flags: ShaderStageFlagsimmutable_samplers: *const SamplerTrait Implementations
Sourceimpl Cast for DescriptorSetLayoutBinding
impl Cast for DescriptorSetLayoutBinding
Sourcetype Target = DescriptorSetLayoutBinding
type Target = DescriptorSetLayoutBinding
The other type this type can be used interchangeably with in FFI.
Sourceimpl Clone for DescriptorSetLayoutBinding
impl Clone for DescriptorSetLayoutBinding
Sourcefn clone(&self) -> DescriptorSetLayoutBinding
fn clone(&self) -> DescriptorSetLayoutBinding
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for DescriptorSetLayoutBinding
Sourceimpl Debug for DescriptorSetLayoutBinding
impl Debug for DescriptorSetLayoutBinding
Sourceimpl Default for DescriptorSetLayoutBinding
impl Default for DescriptorSetLayoutBinding
Sourcefn default() -> DescriptorSetLayoutBinding
fn default() -> DescriptorSetLayoutBinding
Returns the “default value” for a type. Read more
impl Eq for DescriptorSetLayoutBinding
Sourceimpl<'b> HasBuilder<'b> for DescriptorSetLayoutBinding
impl<'b> HasBuilder<'b> for DescriptorSetLayoutBinding
Sourceimpl Hash for DescriptorSetLayoutBinding
impl Hash for DescriptorSetLayoutBinding
Sourceimpl PartialEq for DescriptorSetLayoutBinding
impl PartialEq for DescriptorSetLayoutBinding
Sourcefn eq(&self, other: &DescriptorSetLayoutBinding) -> bool
fn eq(&self, other: &DescriptorSetLayoutBinding) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Send for DescriptorSetLayoutBinding
impl StructuralPartialEq for DescriptorSetLayoutBinding
impl Sync for DescriptorSetLayoutBinding