pub struct ExternalMemoryHandleTypeFlags { /* private fields */ }Expand description
Implementations
Sourceimpl ExternalMemoryHandleTypeFlags
impl ExternalMemoryHandleTypeFlags
pub const OPAQUE_FD: ExternalMemoryHandleTypeFlags
pub const OPAQUE_WIN32: ExternalMemoryHandleTypeFlags
pub const OPAQUE_WIN32_KMT: ExternalMemoryHandleTypeFlags
pub const D3D11_TEXTURE: ExternalMemoryHandleTypeFlags
pub const D3D11_TEXTURE_KMT: ExternalMemoryHandleTypeFlags
pub const D3D12_HEAP: ExternalMemoryHandleTypeFlags
pub const D3D12_RESOURCE: ExternalMemoryHandleTypeFlags
pub const HOST_ALLOCATION_EXT: ExternalMemoryHandleTypeFlags
pub const HOST_MAPPED_FOREIGN_MEMORY_EXT: ExternalMemoryHandleTypeFlags
pub const DMA_BUF_EXT: ExternalMemoryHandleTypeFlags
pub const ANDROID_HARDWARE_BUFFER_ANDROID: ExternalMemoryHandleTypeFlags
pub const ZIRCON_VMO_FUCHSIA: ExternalMemoryHandleTypeFlags
pub const RDMA_ADDRESS_NV: ExternalMemoryHandleTypeFlags
pub const SCI_BUF_NV: ExternalMemoryHandleTypeFlags
pub const SCREEN_BUFFER_QNX: ExternalMemoryHandleTypeFlags
pub const OH_NATIVE_BUFFER_OHOS: ExternalMemoryHandleTypeFlags
pub const MTLBUFFER_EXT: ExternalMemoryHandleTypeFlags
pub const MTLTEXTURE_EXT: ExternalMemoryHandleTypeFlags
pub const MTLHEAP_EXT: ExternalMemoryHandleTypeFlags
Sourcepub const fn empty() -> ExternalMemoryHandleTypeFlags
pub const fn empty() -> ExternalMemoryHandleTypeFlags
Returns an empty set of flags.
Sourcepub const fn all() -> ExternalMemoryHandleTypeFlags
pub const fn all() -> ExternalMemoryHandleTypeFlags
Returns the set containing all flags.
Sourcepub const fn from_bits(bits: u32) -> Option<ExternalMemoryHandleTypeFlags>
pub const fn from_bits(bits: u32) -> Option<ExternalMemoryHandleTypeFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: u32) -> ExternalMemoryHandleTypeFlags
pub const fn from_bits_truncate(bits: u32) -> ExternalMemoryHandleTypeFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(
bits: u32,
) -> ExternalMemoryHandleTypeFlags
pub const unsafe fn from_bits_unchecked( bits: u32, ) -> ExternalMemoryHandleTypeFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
Sourcepub const fn intersects(&self, other: ExternalMemoryHandleTypeFlags) -> bool
pub const fn intersects(&self, other: ExternalMemoryHandleTypeFlags) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: ExternalMemoryHandleTypeFlags) -> bool
pub const fn contains(&self, other: ExternalMemoryHandleTypeFlags) -> bool
Returns true if all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: ExternalMemoryHandleTypeFlags)
pub fn insert(&mut self, other: ExternalMemoryHandleTypeFlags)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: ExternalMemoryHandleTypeFlags)
pub fn remove(&mut self, other: ExternalMemoryHandleTypeFlags)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: ExternalMemoryHandleTypeFlags)
pub fn toggle(&mut self, other: ExternalMemoryHandleTypeFlags)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: ExternalMemoryHandleTypeFlags, value: bool)
pub fn set(&mut self, other: ExternalMemoryHandleTypeFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.
Sourcepub const fn intersection(
self,
other: ExternalMemoryHandleTypeFlags,
) -> ExternalMemoryHandleTypeFlags
pub const fn intersection( self, other: ExternalMemoryHandleTypeFlags, ) -> ExternalMemoryHandleTypeFlags
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
Sourcepub const fn union(
self,
other: ExternalMemoryHandleTypeFlags,
) -> ExternalMemoryHandleTypeFlags
pub const fn union( self, other: ExternalMemoryHandleTypeFlags, ) -> ExternalMemoryHandleTypeFlags
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
Sourcepub const fn difference(
self,
other: ExternalMemoryHandleTypeFlags,
) -> ExternalMemoryHandleTypeFlags
pub const fn difference( self, other: ExternalMemoryHandleTypeFlags, ) -> ExternalMemoryHandleTypeFlags
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
Sourcepub const fn symmetric_difference(
self,
other: ExternalMemoryHandleTypeFlags,
) -> ExternalMemoryHandleTypeFlags
pub const fn symmetric_difference( self, other: ExternalMemoryHandleTypeFlags, ) -> ExternalMemoryHandleTypeFlags
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
Sourcepub const fn complement(self) -> ExternalMemoryHandleTypeFlags
pub const fn complement(self) -> ExternalMemoryHandleTypeFlags
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.