pub struct GeometryInstanceFlagsKHR { /* private fields */ }Expand description
Implementations
Sourceimpl GeometryInstanceFlagsKHR
impl GeometryInstanceFlagsKHR
pub const TRIANGLE_FACING_CULL_DISABLE: GeometryInstanceFlagsKHR
pub const TRIANGLE_FLIP_FACING: GeometryInstanceFlagsKHR
pub const FORCE_OPAQUE: GeometryInstanceFlagsKHR
pub const FORCE_NO_OPAQUE: GeometryInstanceFlagsKHR
pub const FORCE_OPACITY_MICROMAP_2_STATE_EXT: GeometryInstanceFlagsKHR
pub const DISABLE_OPACITY_MICROMAPS_EXT: GeometryInstanceFlagsKHR
Sourcepub const fn empty() -> GeometryInstanceFlagsKHR
pub const fn empty() -> GeometryInstanceFlagsKHR
Returns an empty set of flags.
Sourcepub const fn all() -> GeometryInstanceFlagsKHR
pub const fn all() -> GeometryInstanceFlagsKHR
Returns the set containing all flags.
Sourcepub const fn from_bits(bits: u32) -> Option<GeometryInstanceFlagsKHR>
pub const fn from_bits(bits: u32) -> Option<GeometryInstanceFlagsKHR>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: u32) -> GeometryInstanceFlagsKHR
pub const fn from_bits_truncate(bits: u32) -> GeometryInstanceFlagsKHR
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> GeometryInstanceFlagsKHR
pub const unsafe fn from_bits_unchecked(bits: u32) -> GeometryInstanceFlagsKHR
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
Sourcepub const fn intersects(&self, other: GeometryInstanceFlagsKHR) -> bool
pub const fn intersects(&self, other: GeometryInstanceFlagsKHR) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: GeometryInstanceFlagsKHR) -> bool
pub const fn contains(&self, other: GeometryInstanceFlagsKHR) -> bool
Returns true if all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: GeometryInstanceFlagsKHR)
pub fn insert(&mut self, other: GeometryInstanceFlagsKHR)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: GeometryInstanceFlagsKHR)
pub fn remove(&mut self, other: GeometryInstanceFlagsKHR)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: GeometryInstanceFlagsKHR)
pub fn toggle(&mut self, other: GeometryInstanceFlagsKHR)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: GeometryInstanceFlagsKHR, value: bool)
pub fn set(&mut self, other: GeometryInstanceFlagsKHR, value: bool)
Inserts or removes the specified flags depending on the passed value.
Sourcepub const fn intersection(
self,
other: GeometryInstanceFlagsKHR,
) -> GeometryInstanceFlagsKHR
pub const fn intersection( self, other: GeometryInstanceFlagsKHR, ) -> GeometryInstanceFlagsKHR
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
Sourcepub const fn union(
self,
other: GeometryInstanceFlagsKHR,
) -> GeometryInstanceFlagsKHR
pub const fn union( self, other: GeometryInstanceFlagsKHR, ) -> GeometryInstanceFlagsKHR
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
Sourcepub const fn difference(
self,
other: GeometryInstanceFlagsKHR,
) -> GeometryInstanceFlagsKHR
pub const fn difference( self, other: GeometryInstanceFlagsKHR, ) -> GeometryInstanceFlagsKHR
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
Sourcepub const fn symmetric_difference(
self,
other: GeometryInstanceFlagsKHR,
) -> GeometryInstanceFlagsKHR
pub const fn symmetric_difference( self, other: GeometryInstanceFlagsKHR, ) -> GeometryInstanceFlagsKHR
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
Sourcepub const fn complement(self) -> GeometryInstanceFlagsKHR
pub const fn complement(self) -> GeometryInstanceFlagsKHR
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.