#[repr(C)]pub struct IndirectCommandsLayoutCreateInfoEXT {
pub s_type: StructureType,
pub next: *const c_void,
pub flags: IndirectCommandsLayoutUsageFlagsEXT,
pub shader_stages: ShaderStageFlags,
pub indirect_stride: u32,
pub pipeline_layout: PipelineLayout,
pub token_count: u32,
pub tokens: *const IndirectCommandsLayoutTokenEXT,
}Expand description
Fields
s_type: StructureTypenext: *const c_voidflags: IndirectCommandsLayoutUsageFlagsEXTshader_stages: ShaderStageFlagsindirect_stride: u32pipeline_layout: PipelineLayouttoken_count: u32tokens: *const IndirectCommandsLayoutTokenEXTTrait Implementations
Sourceimpl Cast for IndirectCommandsLayoutCreateInfoEXT
impl Cast for IndirectCommandsLayoutCreateInfoEXT
Sourcetype Target = IndirectCommandsLayoutCreateInfoEXT
type Target = IndirectCommandsLayoutCreateInfoEXT
The other type this type can be used interchangeably with in FFI.
Sourceimpl Clone for IndirectCommandsLayoutCreateInfoEXT
impl Clone for IndirectCommandsLayoutCreateInfoEXT
Sourcefn clone(&self) -> IndirectCommandsLayoutCreateInfoEXT
fn clone(&self) -> IndirectCommandsLayoutCreateInfoEXT
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for IndirectCommandsLayoutCreateInfoEXT
impl Default for IndirectCommandsLayoutCreateInfoEXT
Sourcefn default() -> IndirectCommandsLayoutCreateInfoEXT
fn default() -> IndirectCommandsLayoutCreateInfoEXT
Returns the “default value” for a type. Read more
Sourceimpl<'b> HasBuilder<'b> for IndirectCommandsLayoutCreateInfoEXT
impl<'b> HasBuilder<'b> for IndirectCommandsLayoutCreateInfoEXT
Sourceimpl PartialEq for IndirectCommandsLayoutCreateInfoEXT
impl PartialEq for IndirectCommandsLayoutCreateInfoEXT
Sourcefn eq(&self, other: &IndirectCommandsLayoutCreateInfoEXT) -> bool
fn eq(&self, other: &IndirectCommandsLayoutCreateInfoEXT) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for IndirectCommandsLayoutCreateInfoEXT
impl Eq for IndirectCommandsLayoutCreateInfoEXT
impl Send for IndirectCommandsLayoutCreateInfoEXT
impl StructuralPartialEq for IndirectCommandsLayoutCreateInfoEXT
impl Sync for IndirectCommandsLayoutCreateInfoEXT