#[repr(C)]pub struct IndirectCommandsLayoutPushDataTokenNV {
pub s_type: StructureType,
pub next: *const c_void,
pub push_data_offset: u32,
pub push_data_size: u32,
}Expand description
Fields
s_type: StructureTypenext: *const c_voidpush_data_offset: u32push_data_size: u32Trait Implementations
Sourceimpl Cast for IndirectCommandsLayoutPushDataTokenNV
impl Cast for IndirectCommandsLayoutPushDataTokenNV
Sourcetype Target = IndirectCommandsLayoutPushDataTokenNV
type Target = IndirectCommandsLayoutPushDataTokenNV
The other type this type can be used interchangeably with in FFI.
Sourceimpl Clone for IndirectCommandsLayoutPushDataTokenNV
impl Clone for IndirectCommandsLayoutPushDataTokenNV
Sourcefn clone(&self) -> IndirectCommandsLayoutPushDataTokenNV
fn clone(&self) -> IndirectCommandsLayoutPushDataTokenNV
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for IndirectCommandsLayoutPushDataTokenNV
impl Default for IndirectCommandsLayoutPushDataTokenNV
Sourcefn default() -> IndirectCommandsLayoutPushDataTokenNV
fn default() -> IndirectCommandsLayoutPushDataTokenNV
Returns the “default value” for a type. Read more
Sourceimpl HasBuilder<'static> for IndirectCommandsLayoutPushDataTokenNV
impl HasBuilder<'static> for IndirectCommandsLayoutPushDataTokenNV
Sourceimpl PartialEq for IndirectCommandsLayoutPushDataTokenNV
impl PartialEq for IndirectCommandsLayoutPushDataTokenNV
Sourcefn eq(&self, other: &IndirectCommandsLayoutPushDataTokenNV) -> bool
fn eq(&self, other: &IndirectCommandsLayoutPushDataTokenNV) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for IndirectCommandsLayoutPushDataTokenNV
impl Eq for IndirectCommandsLayoutPushDataTokenNV
impl ExtendsIndirectCommandsLayoutTokenNV for IndirectCommandsLayoutPushDataTokenNV
impl Send for IndirectCommandsLayoutPushDataTokenNV
impl StructuralPartialEq for IndirectCommandsLayoutPushDataTokenNV
impl Sync for IndirectCommandsLayoutPushDataTokenNV