#[repr(C)]pub struct OpticalFlowSessionCreateInfoNV {
pub s_type: StructureType,
pub next: *mut c_void,
pub width: u32,
pub height: u32,
pub image_format: Format,
pub flow_vector_format: Format,
pub cost_format: Format,
pub output_grid_size: OpticalFlowGridSizeFlagsNV,
pub hint_grid_size: OpticalFlowGridSizeFlagsNV,
pub performance_level: OpticalFlowPerformanceLevelNV,
pub flags: OpticalFlowSessionCreateFlagsNV,
}Expand description
Fields
s_type: StructureTypenext: *mut c_voidwidth: u32height: u32image_format: Formatflow_vector_format: Formatcost_format: Formatoutput_grid_size: OpticalFlowGridSizeFlagsNVhint_grid_size: OpticalFlowGridSizeFlagsNVperformance_level: OpticalFlowPerformanceLevelNVflags: OpticalFlowSessionCreateFlagsNVTrait Implementations
Sourceimpl Cast for OpticalFlowSessionCreateInfoNV
impl Cast for OpticalFlowSessionCreateInfoNV
Sourcetype Target = OpticalFlowSessionCreateInfoNV
type Target = OpticalFlowSessionCreateInfoNV
The other type this type can be used interchangeably with in FFI.
Sourceimpl Clone for OpticalFlowSessionCreateInfoNV
impl Clone for OpticalFlowSessionCreateInfoNV
Sourcefn clone(&self) -> OpticalFlowSessionCreateInfoNV
fn clone(&self) -> OpticalFlowSessionCreateInfoNV
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for OpticalFlowSessionCreateInfoNV
impl Default for OpticalFlowSessionCreateInfoNV
Sourcefn default() -> OpticalFlowSessionCreateInfoNV
fn default() -> OpticalFlowSessionCreateInfoNV
Returns the “default value” for a type. Read more
Sourceimpl<'b> HasBuilder<'b> for OpticalFlowSessionCreateInfoNV
impl<'b> HasBuilder<'b> for OpticalFlowSessionCreateInfoNV
Sourceimpl PartialEq for OpticalFlowSessionCreateInfoNV
impl PartialEq for OpticalFlowSessionCreateInfoNV
Sourcefn eq(&self, other: &OpticalFlowSessionCreateInfoNV) -> bool
fn eq(&self, other: &OpticalFlowSessionCreateInfoNV) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for OpticalFlowSessionCreateInfoNV
impl Eq for OpticalFlowSessionCreateInfoNV
impl Send for OpticalFlowSessionCreateInfoNV
impl StructuralPartialEq for OpticalFlowSessionCreateInfoNV
impl Sync for OpticalFlowSessionCreateInfoNV