#[repr(C)]pub struct PhysicalDeviceCustomResolveFeaturesEXT {
pub s_type: StructureType,
pub next: *mut c_void,
pub custom_resolve: u32,
}Expand description
Fields
s_type: StructureTypenext: *mut c_voidcustom_resolve: u32Trait Implementations
Sourceimpl Cast for PhysicalDeviceCustomResolveFeaturesEXT
impl Cast for PhysicalDeviceCustomResolveFeaturesEXT
Sourcetype Target = PhysicalDeviceCustomResolveFeaturesEXT
type Target = PhysicalDeviceCustomResolveFeaturesEXT
The other type this type can be used interchangeably with in FFI.
Sourceimpl Clone for PhysicalDeviceCustomResolveFeaturesEXT
impl Clone for PhysicalDeviceCustomResolveFeaturesEXT
Sourcefn clone(&self) -> PhysicalDeviceCustomResolveFeaturesEXT
fn clone(&self) -> PhysicalDeviceCustomResolveFeaturesEXT
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for PhysicalDeviceCustomResolveFeaturesEXT
impl Default for PhysicalDeviceCustomResolveFeaturesEXT
Sourcefn default() -> PhysicalDeviceCustomResolveFeaturesEXT
fn default() -> PhysicalDeviceCustomResolveFeaturesEXT
Returns the “default value” for a type. Read more
Sourceimpl HasBuilder<'static> for PhysicalDeviceCustomResolveFeaturesEXT
impl HasBuilder<'static> for PhysicalDeviceCustomResolveFeaturesEXT
Sourceimpl PartialEq for PhysicalDeviceCustomResolveFeaturesEXT
impl PartialEq for PhysicalDeviceCustomResolveFeaturesEXT
Sourcefn eq(&self, other: &PhysicalDeviceCustomResolveFeaturesEXT) -> bool
fn eq(&self, other: &PhysicalDeviceCustomResolveFeaturesEXT) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for PhysicalDeviceCustomResolveFeaturesEXT
impl Eq for PhysicalDeviceCustomResolveFeaturesEXT
impl ExtendsDeviceCreateInfo for PhysicalDeviceCustomResolveFeaturesEXT
impl ExtendsPhysicalDeviceFeatures2 for PhysicalDeviceCustomResolveFeaturesEXT
impl Send for PhysicalDeviceCustomResolveFeaturesEXT
impl StructuralPartialEq for PhysicalDeviceCustomResolveFeaturesEXT
impl Sync for PhysicalDeviceCustomResolveFeaturesEXT