#[repr(C)]pub struct PhysicalDeviceDataGraphModelFeaturesQCOM {
pub s_type: StructureType,
pub next: *mut c_void,
pub data_graph_model: u32,
}Expand description
Fields
s_type: StructureTypenext: *mut c_voiddata_graph_model: u32Trait Implementations
Sourceimpl Cast for PhysicalDeviceDataGraphModelFeaturesQCOM
impl Cast for PhysicalDeviceDataGraphModelFeaturesQCOM
Sourcetype Target = PhysicalDeviceDataGraphModelFeaturesQCOM
type Target = PhysicalDeviceDataGraphModelFeaturesQCOM
The other type this type can be used interchangeably with in FFI.
Sourceimpl Clone for PhysicalDeviceDataGraphModelFeaturesQCOM
impl Clone for PhysicalDeviceDataGraphModelFeaturesQCOM
Sourcefn clone(&self) -> PhysicalDeviceDataGraphModelFeaturesQCOM
fn clone(&self) -> PhysicalDeviceDataGraphModelFeaturesQCOM
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for PhysicalDeviceDataGraphModelFeaturesQCOM
impl Default for PhysicalDeviceDataGraphModelFeaturesQCOM
Sourcefn default() -> PhysicalDeviceDataGraphModelFeaturesQCOM
fn default() -> PhysicalDeviceDataGraphModelFeaturesQCOM
Returns the “default value” for a type. Read more
Sourceimpl HasBuilder<'static> for PhysicalDeviceDataGraphModelFeaturesQCOM
impl HasBuilder<'static> for PhysicalDeviceDataGraphModelFeaturesQCOM
Sourceimpl InputChainStruct for PhysicalDeviceDataGraphModelFeaturesQCOM
impl InputChainStruct for PhysicalDeviceDataGraphModelFeaturesQCOM
Sourceconst TYPE: StructureType = StructureType::PHYSICAL_DEVICE_DATA_GRAPH_MODEL_FEATURES_QCOM
const TYPE: StructureType = StructureType::PHYSICAL_DEVICE_DATA_GRAPH_MODEL_FEATURES_QCOM
The structure type for this struct type.
Sourcefn s_type(&self) -> StructureType
fn s_type(&self) -> StructureType
The structure type for this struct.
Sourceimpl PartialEq for PhysicalDeviceDataGraphModelFeaturesQCOM
impl PartialEq for PhysicalDeviceDataGraphModelFeaturesQCOM
Sourcefn eq(&self, other: &PhysicalDeviceDataGraphModelFeaturesQCOM) -> bool
fn eq(&self, other: &PhysicalDeviceDataGraphModelFeaturesQCOM) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for PhysicalDeviceDataGraphModelFeaturesQCOM
impl Eq for PhysicalDeviceDataGraphModelFeaturesQCOM
impl ExtendsDeviceCreateInfo for PhysicalDeviceDataGraphModelFeaturesQCOM
impl ExtendsPhysicalDeviceFeatures2 for PhysicalDeviceDataGraphModelFeaturesQCOM
impl Send for PhysicalDeviceDataGraphModelFeaturesQCOM
impl StructuralPartialEq for PhysicalDeviceDataGraphModelFeaturesQCOM
impl Sync for PhysicalDeviceDataGraphModelFeaturesQCOM