#[repr(C)]pub struct PhysicalDeviceDescriptorHeapTensorPropertiesARM {
pub s_type: StructureType,
pub next: *mut c_void,
pub tensor_descriptor_size: u64,
pub tensor_descriptor_alignment: u64,
pub tensor_capture_replay_opaque_data_size: usize,
}Expand description
Fields
s_type: StructureTypenext: *mut c_voidtensor_descriptor_size: u64tensor_descriptor_alignment: u64tensor_capture_replay_opaque_data_size: usizeTrait Implementations
Sourceimpl Cast for PhysicalDeviceDescriptorHeapTensorPropertiesARM
impl Cast for PhysicalDeviceDescriptorHeapTensorPropertiesARM
Sourcetype Target = PhysicalDeviceDescriptorHeapTensorPropertiesARM
type Target = PhysicalDeviceDescriptorHeapTensorPropertiesARM
The other type this type can be used interchangeably with in FFI.
Sourceimpl Clone for PhysicalDeviceDescriptorHeapTensorPropertiesARM
impl Clone for PhysicalDeviceDescriptorHeapTensorPropertiesARM
Sourcefn clone(&self) -> PhysicalDeviceDescriptorHeapTensorPropertiesARM
fn clone(&self) -> PhysicalDeviceDescriptorHeapTensorPropertiesARM
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for PhysicalDeviceDescriptorHeapTensorPropertiesARM
impl Default for PhysicalDeviceDescriptorHeapTensorPropertiesARM
Sourcefn default() -> PhysicalDeviceDescriptorHeapTensorPropertiesARM
fn default() -> PhysicalDeviceDescriptorHeapTensorPropertiesARM
Returns the “default value” for a type. Read more
Sourceimpl HasBuilder<'static> for PhysicalDeviceDescriptorHeapTensorPropertiesARM
impl HasBuilder<'static> for PhysicalDeviceDescriptorHeapTensorPropertiesARM
Sourceimpl InputChainStruct for PhysicalDeviceDescriptorHeapTensorPropertiesARM
impl InputChainStruct for PhysicalDeviceDescriptorHeapTensorPropertiesARM
Sourceconst TYPE: StructureType = StructureType::PHYSICAL_DEVICE_DESCRIPTOR_HEAP_TENSOR_PROPERTIES_ARM
const TYPE: StructureType = StructureType::PHYSICAL_DEVICE_DESCRIPTOR_HEAP_TENSOR_PROPERTIES_ARM
The structure type for this struct type.
Sourcefn s_type(&self) -> StructureType
fn s_type(&self) -> StructureType
The structure type for this struct.
Sourceimpl PartialEq for PhysicalDeviceDescriptorHeapTensorPropertiesARM
impl PartialEq for PhysicalDeviceDescriptorHeapTensorPropertiesARM
Sourcefn eq(&self, other: &PhysicalDeviceDescriptorHeapTensorPropertiesARM) -> bool
fn eq(&self, other: &PhysicalDeviceDescriptorHeapTensorPropertiesARM) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for PhysicalDeviceDescriptorHeapTensorPropertiesARM
impl Eq for PhysicalDeviceDescriptorHeapTensorPropertiesARM
impl ExtendsPhysicalDeviceProperties2 for PhysicalDeviceDescriptorHeapTensorPropertiesARM
impl Send for PhysicalDeviceDescriptorHeapTensorPropertiesARM
impl StructuralPartialEq for PhysicalDeviceDescriptorHeapTensorPropertiesARM
impl Sync for PhysicalDeviceDescriptorHeapTensorPropertiesARM