#[repr(C)]pub struct PhysicalDeviceExternalComputeQueuePropertiesNV {
pub s_type: StructureType,
pub next: *mut c_void,
pub external_data_size: u32,
pub max_external_queues: u32,
}Expand description
Fields
s_type: StructureTypenext: *mut c_voidexternal_data_size: u32max_external_queues: u32Trait Implementations
Sourceimpl Cast for PhysicalDeviceExternalComputeQueuePropertiesNV
impl Cast for PhysicalDeviceExternalComputeQueuePropertiesNV
Sourcetype Target = PhysicalDeviceExternalComputeQueuePropertiesNV
type Target = PhysicalDeviceExternalComputeQueuePropertiesNV
The other type this type can be used interchangeably with in FFI.
Sourceimpl Clone for PhysicalDeviceExternalComputeQueuePropertiesNV
impl Clone for PhysicalDeviceExternalComputeQueuePropertiesNV
Sourcefn clone(&self) -> PhysicalDeviceExternalComputeQueuePropertiesNV
fn clone(&self) -> PhysicalDeviceExternalComputeQueuePropertiesNV
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for PhysicalDeviceExternalComputeQueuePropertiesNV
impl Default for PhysicalDeviceExternalComputeQueuePropertiesNV
Sourcefn default() -> PhysicalDeviceExternalComputeQueuePropertiesNV
fn default() -> PhysicalDeviceExternalComputeQueuePropertiesNV
Returns the “default value” for a type. Read more
Sourceimpl HasBuilder<'static> for PhysicalDeviceExternalComputeQueuePropertiesNV
impl HasBuilder<'static> for PhysicalDeviceExternalComputeQueuePropertiesNV
Sourceimpl InputChainStruct for PhysicalDeviceExternalComputeQueuePropertiesNV
impl InputChainStruct for PhysicalDeviceExternalComputeQueuePropertiesNV
Sourceconst TYPE: StructureType = StructureType::PHYSICAL_DEVICE_EXTERNAL_COMPUTE_QUEUE_PROPERTIES_NV
const TYPE: StructureType = StructureType::PHYSICAL_DEVICE_EXTERNAL_COMPUTE_QUEUE_PROPERTIES_NV
The structure type for this struct type.
Sourcefn s_type(&self) -> StructureType
fn s_type(&self) -> StructureType
The structure type for this struct.
Sourceimpl PartialEq for PhysicalDeviceExternalComputeQueuePropertiesNV
impl PartialEq for PhysicalDeviceExternalComputeQueuePropertiesNV
Sourcefn eq(&self, other: &PhysicalDeviceExternalComputeQueuePropertiesNV) -> bool
fn eq(&self, other: &PhysicalDeviceExternalComputeQueuePropertiesNV) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for PhysicalDeviceExternalComputeQueuePropertiesNV
impl Eq for PhysicalDeviceExternalComputeQueuePropertiesNV
impl ExtendsPhysicalDeviceProperties2 for PhysicalDeviceExternalComputeQueuePropertiesNV
impl Send for PhysicalDeviceExternalComputeQueuePropertiesNV
impl StructuralPartialEq for PhysicalDeviceExternalComputeQueuePropertiesNV
impl Sync for PhysicalDeviceExternalComputeQueuePropertiesNV