#[repr(C)]pub struct PhysicalDeviceFragmentDensityMapOffsetFeaturesEXT {
pub s_type: StructureType,
pub next: *mut c_void,
pub fragment_density_map_offset: u32,
}Expand description
Fields
s_type: StructureTypenext: *mut c_voidfragment_density_map_offset: u32Trait Implementations
Sourceimpl Cast for PhysicalDeviceFragmentDensityMapOffsetFeaturesEXT
impl Cast for PhysicalDeviceFragmentDensityMapOffsetFeaturesEXT
Sourcetype Target = PhysicalDeviceFragmentDensityMapOffsetFeaturesEXT
type Target = PhysicalDeviceFragmentDensityMapOffsetFeaturesEXT
The other type this type can be used interchangeably with in FFI.
Sourceimpl Clone for PhysicalDeviceFragmentDensityMapOffsetFeaturesEXT
impl Clone for PhysicalDeviceFragmentDensityMapOffsetFeaturesEXT
Sourcefn clone(&self) -> PhysicalDeviceFragmentDensityMapOffsetFeaturesEXT
fn clone(&self) -> PhysicalDeviceFragmentDensityMapOffsetFeaturesEXT
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for PhysicalDeviceFragmentDensityMapOffsetFeaturesEXT
impl Default for PhysicalDeviceFragmentDensityMapOffsetFeaturesEXT
Sourcefn default() -> PhysicalDeviceFragmentDensityMapOffsetFeaturesEXT
fn default() -> PhysicalDeviceFragmentDensityMapOffsetFeaturesEXT
Returns the “default value” for a type. Read more
Sourceimpl HasBuilder<'static> for PhysicalDeviceFragmentDensityMapOffsetFeaturesEXT
impl HasBuilder<'static> for PhysicalDeviceFragmentDensityMapOffsetFeaturesEXT
Sourceimpl InputChainStruct for PhysicalDeviceFragmentDensityMapOffsetFeaturesEXT
impl InputChainStruct for PhysicalDeviceFragmentDensityMapOffsetFeaturesEXT
Sourceconst TYPE: StructureType = StructureType::PHYSICAL_DEVICE_FRAGMENT_DENSITY_MAP_OFFSET_FEATURES_EXT
const TYPE: StructureType = StructureType::PHYSICAL_DEVICE_FRAGMENT_DENSITY_MAP_OFFSET_FEATURES_EXT
The structure type for this struct type.
Sourcefn s_type(&self) -> StructureType
fn s_type(&self) -> StructureType
The structure type for this struct.
Sourceimpl PartialEq for PhysicalDeviceFragmentDensityMapOffsetFeaturesEXT
impl PartialEq for PhysicalDeviceFragmentDensityMapOffsetFeaturesEXT
Sourcefn eq(&self, other: &PhysicalDeviceFragmentDensityMapOffsetFeaturesEXT) -> bool
fn eq(&self, other: &PhysicalDeviceFragmentDensityMapOffsetFeaturesEXT) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for PhysicalDeviceFragmentDensityMapOffsetFeaturesEXT
impl Eq for PhysicalDeviceFragmentDensityMapOffsetFeaturesEXT
impl ExtendsDeviceCreateInfo for PhysicalDeviceFragmentDensityMapOffsetFeaturesEXT
impl ExtendsPhysicalDeviceFeatures2 for PhysicalDeviceFragmentDensityMapOffsetFeaturesEXT
impl Send for PhysicalDeviceFragmentDensityMapOffsetFeaturesEXT
impl StructuralPartialEq for PhysicalDeviceFragmentDensityMapOffsetFeaturesEXT
impl Sync for PhysicalDeviceFragmentDensityMapOffsetFeaturesEXT