#[repr(C)]pub struct PhysicalDeviceHostImageCopyFeatures {
pub s_type: StructureType,
pub next: *mut c_void,
pub host_image_copy: u32,
}Expand description
Fields
s_type: StructureTypenext: *mut c_voidhost_image_copy: u32Trait Implementations
Sourceimpl Cast for PhysicalDeviceHostImageCopyFeatures
impl Cast for PhysicalDeviceHostImageCopyFeatures
Sourcetype Target = PhysicalDeviceHostImageCopyFeatures
type Target = PhysicalDeviceHostImageCopyFeatures
The other type this type can be used interchangeably with in FFI.
Sourceimpl Clone for PhysicalDeviceHostImageCopyFeatures
impl Clone for PhysicalDeviceHostImageCopyFeatures
Sourcefn clone(&self) -> PhysicalDeviceHostImageCopyFeatures
fn clone(&self) -> PhysicalDeviceHostImageCopyFeatures
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for PhysicalDeviceHostImageCopyFeatures
impl Default for PhysicalDeviceHostImageCopyFeatures
Sourcefn default() -> PhysicalDeviceHostImageCopyFeatures
fn default() -> PhysicalDeviceHostImageCopyFeatures
Returns the “default value” for a type. Read more
Sourceimpl HasBuilder<'static> for PhysicalDeviceHostImageCopyFeatures
impl HasBuilder<'static> for PhysicalDeviceHostImageCopyFeatures
Sourceimpl PartialEq for PhysicalDeviceHostImageCopyFeatures
impl PartialEq for PhysicalDeviceHostImageCopyFeatures
Sourcefn eq(&self, other: &PhysicalDeviceHostImageCopyFeatures) -> bool
fn eq(&self, other: &PhysicalDeviceHostImageCopyFeatures) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for PhysicalDeviceHostImageCopyFeatures
impl Eq for PhysicalDeviceHostImageCopyFeatures
impl ExtendsDeviceCreateInfo for PhysicalDeviceHostImageCopyFeatures
impl ExtendsPhysicalDeviceFeatures2 for PhysicalDeviceHostImageCopyFeatures
impl Send for PhysicalDeviceHostImageCopyFeatures
impl StructuralPartialEq for PhysicalDeviceHostImageCopyFeatures
impl Sync for PhysicalDeviceHostImageCopyFeatures