#[repr(C)]pub struct PhysicalDeviceImageAlignmentControlFeaturesMESA {
pub s_type: StructureType,
pub next: *mut c_void,
pub image_alignment_control: u32,
}Expand description
Fields
s_type: StructureTypenext: *mut c_voidimage_alignment_control: u32Trait Implementations
Sourceimpl Cast for PhysicalDeviceImageAlignmentControlFeaturesMESA
impl Cast for PhysicalDeviceImageAlignmentControlFeaturesMESA
Sourcetype Target = PhysicalDeviceImageAlignmentControlFeaturesMESA
type Target = PhysicalDeviceImageAlignmentControlFeaturesMESA
The other type this type can be used interchangeably with in FFI.
Sourceimpl Clone for PhysicalDeviceImageAlignmentControlFeaturesMESA
impl Clone for PhysicalDeviceImageAlignmentControlFeaturesMESA
Sourcefn clone(&self) -> PhysicalDeviceImageAlignmentControlFeaturesMESA
fn clone(&self) -> PhysicalDeviceImageAlignmentControlFeaturesMESA
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for PhysicalDeviceImageAlignmentControlFeaturesMESA
impl Default for PhysicalDeviceImageAlignmentControlFeaturesMESA
Sourcefn default() -> PhysicalDeviceImageAlignmentControlFeaturesMESA
fn default() -> PhysicalDeviceImageAlignmentControlFeaturesMESA
Returns the “default value” for a type. Read more
Sourceimpl HasBuilder<'static> for PhysicalDeviceImageAlignmentControlFeaturesMESA
impl HasBuilder<'static> for PhysicalDeviceImageAlignmentControlFeaturesMESA
Sourceimpl InputChainStruct for PhysicalDeviceImageAlignmentControlFeaturesMESA
impl InputChainStruct for PhysicalDeviceImageAlignmentControlFeaturesMESA
Sourceconst TYPE: StructureType = StructureType::PHYSICAL_DEVICE_IMAGE_ALIGNMENT_CONTROL_FEATURES_MESA
const TYPE: StructureType = StructureType::PHYSICAL_DEVICE_IMAGE_ALIGNMENT_CONTROL_FEATURES_MESA
The structure type for this struct type.
Sourcefn s_type(&self) -> StructureType
fn s_type(&self) -> StructureType
The structure type for this struct.
Sourceimpl PartialEq for PhysicalDeviceImageAlignmentControlFeaturesMESA
impl PartialEq for PhysicalDeviceImageAlignmentControlFeaturesMESA
Sourcefn eq(&self, other: &PhysicalDeviceImageAlignmentControlFeaturesMESA) -> bool
fn eq(&self, other: &PhysicalDeviceImageAlignmentControlFeaturesMESA) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for PhysicalDeviceImageAlignmentControlFeaturesMESA
impl Eq for PhysicalDeviceImageAlignmentControlFeaturesMESA
impl ExtendsDeviceCreateInfo for PhysicalDeviceImageAlignmentControlFeaturesMESA
impl ExtendsPhysicalDeviceFeatures2 for PhysicalDeviceImageAlignmentControlFeaturesMESA
impl Send for PhysicalDeviceImageAlignmentControlFeaturesMESA
impl StructuralPartialEq for PhysicalDeviceImageAlignmentControlFeaturesMESA
impl Sync for PhysicalDeviceImageAlignmentControlFeaturesMESA