#[repr(C)]pub struct PhysicalDeviceNestedCommandBufferPropertiesEXT {
pub s_type: StructureType,
pub next: *mut c_void,
pub max_command_buffer_nesting_level: u32,
}Expand description
Fields
s_type: StructureTypenext: *mut c_voidmax_command_buffer_nesting_level: u32Trait Implementations
Sourceimpl Cast for PhysicalDeviceNestedCommandBufferPropertiesEXT
impl Cast for PhysicalDeviceNestedCommandBufferPropertiesEXT
Sourcetype Target = PhysicalDeviceNestedCommandBufferPropertiesEXT
type Target = PhysicalDeviceNestedCommandBufferPropertiesEXT
The other type this type can be used interchangeably with in FFI.
Sourceimpl Clone for PhysicalDeviceNestedCommandBufferPropertiesEXT
impl Clone for PhysicalDeviceNestedCommandBufferPropertiesEXT
Sourcefn clone(&self) -> PhysicalDeviceNestedCommandBufferPropertiesEXT
fn clone(&self) -> PhysicalDeviceNestedCommandBufferPropertiesEXT
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for PhysicalDeviceNestedCommandBufferPropertiesEXT
impl Default for PhysicalDeviceNestedCommandBufferPropertiesEXT
Sourcefn default() -> PhysicalDeviceNestedCommandBufferPropertiesEXT
fn default() -> PhysicalDeviceNestedCommandBufferPropertiesEXT
Returns the “default value” for a type. Read more
Sourceimpl HasBuilder<'static> for PhysicalDeviceNestedCommandBufferPropertiesEXT
impl HasBuilder<'static> for PhysicalDeviceNestedCommandBufferPropertiesEXT
Sourceimpl InputChainStruct for PhysicalDeviceNestedCommandBufferPropertiesEXT
impl InputChainStruct for PhysicalDeviceNestedCommandBufferPropertiesEXT
Sourceconst TYPE: StructureType = StructureType::PHYSICAL_DEVICE_NESTED_COMMAND_BUFFER_PROPERTIES_EXT
const TYPE: StructureType = StructureType::PHYSICAL_DEVICE_NESTED_COMMAND_BUFFER_PROPERTIES_EXT
The structure type for this struct type.
Sourcefn s_type(&self) -> StructureType
fn s_type(&self) -> StructureType
The structure type for this struct.
Sourceimpl PartialEq for PhysicalDeviceNestedCommandBufferPropertiesEXT
impl PartialEq for PhysicalDeviceNestedCommandBufferPropertiesEXT
Sourcefn eq(&self, other: &PhysicalDeviceNestedCommandBufferPropertiesEXT) -> bool
fn eq(&self, other: &PhysicalDeviceNestedCommandBufferPropertiesEXT) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for PhysicalDeviceNestedCommandBufferPropertiesEXT
impl Eq for PhysicalDeviceNestedCommandBufferPropertiesEXT
impl ExtendsPhysicalDeviceProperties2 for PhysicalDeviceNestedCommandBufferPropertiesEXT
impl Send for PhysicalDeviceNestedCommandBufferPropertiesEXT
impl StructuralPartialEq for PhysicalDeviceNestedCommandBufferPropertiesEXT
impl Sync for PhysicalDeviceNestedCommandBufferPropertiesEXT