#[repr(C)]pub struct PhysicalDeviceRasterizationOrderAttachmentAccessFeaturesEXT {
pub s_type: StructureType,
pub next: *mut c_void,
pub rasterization_order_color_attachment_access: u32,
pub rasterization_order_depth_attachment_access: u32,
pub rasterization_order_stencil_attachment_access: u32,
}Expand description
Fields
s_type: StructureTypenext: *mut c_voidrasterization_order_color_attachment_access: u32rasterization_order_depth_attachment_access: u32rasterization_order_stencil_attachment_access: u32Trait Implementations
Sourceimpl Cast for PhysicalDeviceRasterizationOrderAttachmentAccessFeaturesEXT
impl Cast for PhysicalDeviceRasterizationOrderAttachmentAccessFeaturesEXT
Sourcetype Target = PhysicalDeviceRasterizationOrderAttachmentAccessFeaturesEXT
type Target = PhysicalDeviceRasterizationOrderAttachmentAccessFeaturesEXT
The other type this type can be used interchangeably with in FFI.
Sourceimpl Clone for PhysicalDeviceRasterizationOrderAttachmentAccessFeaturesEXT
impl Clone for PhysicalDeviceRasterizationOrderAttachmentAccessFeaturesEXT
Sourcefn clone(&self) -> PhysicalDeviceRasterizationOrderAttachmentAccessFeaturesEXT
fn clone(&self) -> PhysicalDeviceRasterizationOrderAttachmentAccessFeaturesEXT
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for PhysicalDeviceRasterizationOrderAttachmentAccessFeaturesEXT
impl Default for PhysicalDeviceRasterizationOrderAttachmentAccessFeaturesEXT
Sourcefn default() -> PhysicalDeviceRasterizationOrderAttachmentAccessFeaturesEXT
fn default() -> PhysicalDeviceRasterizationOrderAttachmentAccessFeaturesEXT
Returns the “default value” for a type. Read more
Sourceimpl HasBuilder<'static> for PhysicalDeviceRasterizationOrderAttachmentAccessFeaturesEXT
impl HasBuilder<'static> for PhysicalDeviceRasterizationOrderAttachmentAccessFeaturesEXT
Sourceimpl InputChainStruct for PhysicalDeviceRasterizationOrderAttachmentAccessFeaturesEXT
impl InputChainStruct for PhysicalDeviceRasterizationOrderAttachmentAccessFeaturesEXT
Sourceconst TYPE: StructureType = StructureType::PHYSICAL_DEVICE_RASTERIZATION_ORDER_ATTACHMENT_ACCESS_FEATURES_EXT
const TYPE: StructureType = StructureType::PHYSICAL_DEVICE_RASTERIZATION_ORDER_ATTACHMENT_ACCESS_FEATURES_EXT
The structure type for this struct type.
Sourcefn s_type(&self) -> StructureType
fn s_type(&self) -> StructureType
The structure type for this struct.
Sourceimpl PartialEq for PhysicalDeviceRasterizationOrderAttachmentAccessFeaturesEXT
impl PartialEq for PhysicalDeviceRasterizationOrderAttachmentAccessFeaturesEXT
Sourcefn eq(
&self,
other: &PhysicalDeviceRasterizationOrderAttachmentAccessFeaturesEXT,
) -> bool
fn eq( &self, other: &PhysicalDeviceRasterizationOrderAttachmentAccessFeaturesEXT, ) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for PhysicalDeviceRasterizationOrderAttachmentAccessFeaturesEXT
impl Eq for PhysicalDeviceRasterizationOrderAttachmentAccessFeaturesEXT
impl ExtendsDeviceCreateInfo for PhysicalDeviceRasterizationOrderAttachmentAccessFeaturesEXT
impl ExtendsPhysicalDeviceFeatures2 for PhysicalDeviceRasterizationOrderAttachmentAccessFeaturesEXT
impl Send for PhysicalDeviceRasterizationOrderAttachmentAccessFeaturesEXT
impl StructuralPartialEq for PhysicalDeviceRasterizationOrderAttachmentAccessFeaturesEXT
impl Sync for PhysicalDeviceRasterizationOrderAttachmentAccessFeaturesEXT