pub struct PipelineCreateFlags2 { /* private fields */ }Expand description
Implementations
Sourceimpl PipelineCreateFlags2
impl PipelineCreateFlags2
pub const DISABLE_OPTIMIZATION: PipelineCreateFlags2
pub const ALLOW_DERIVATIVES: PipelineCreateFlags2
pub const DERIVATIVE: PipelineCreateFlags2
pub const VIEW_INDEX_FROM_DEVICE_INDEX: PipelineCreateFlags2
pub const DISPATCH_BASE: PipelineCreateFlags2
pub const DEFER_COMPILE_NV: PipelineCreateFlags2
pub const CAPTURE_STATISTICS_KHR: PipelineCreateFlags2
pub const CAPTURE_INTERNAL_REPRESENTATIONS_KHR: PipelineCreateFlags2
pub const FAIL_ON_PIPELINE_COMPILE_REQUIRED: PipelineCreateFlags2
pub const EARLY_RETURN_ON_FAILURE: PipelineCreateFlags2
pub const LINK_TIME_OPTIMIZATION_EXT: PipelineCreateFlags2
pub const LIBRARY_KHR: PipelineCreateFlags2
pub const RAY_TRACING_SKIP_TRIANGLES_KHR: PipelineCreateFlags2
pub const RAY_TRACING_SKIP_AABBS_KHR: PipelineCreateFlags2
pub const RAY_TRACING_NO_NULL_ANY_HIT_SHADERS_KHR: PipelineCreateFlags2
pub const RAY_TRACING_NO_NULL_CLOSEST_HIT_SHADERS_KHR: PipelineCreateFlags2
pub const RAY_TRACING_NO_NULL_MISS_SHADERS_KHR: PipelineCreateFlags2
pub const RAY_TRACING_NO_NULL_INTERSECTION_SHADERS_KHR: PipelineCreateFlags2
pub const INDIRECT_BINDABLE_NV: PipelineCreateFlags2
pub const RAY_TRACING_SHADER_GROUP_HANDLE_CAPTURE_REPLAY_KHR: PipelineCreateFlags2
pub const RAY_TRACING_ALLOW_MOTION_NV: PipelineCreateFlags2
pub const RENDERING_FRAGMENT_SHADING_RATE_ATTACHMENT_KHR: PipelineCreateFlags2
pub const RENDERING_FRAGMENT_DENSITY_MAP_ATTACHMENT_EXT: PipelineCreateFlags2
pub const RETAIN_LINK_TIME_OPTIMIZATION_INFO_EXT: PipelineCreateFlags2
pub const RAY_TRACING_OPACITY_MICROMAP_EXT: PipelineCreateFlags2
pub const COLOR_ATTACHMENT_FEEDBACK_LOOP_EXT: PipelineCreateFlags2
pub const DEPTH_STENCIL_ATTACHMENT_FEEDBACK_LOOP_EXT: PipelineCreateFlags2
pub const NO_PROTECTED_ACCESS: PipelineCreateFlags2
pub const RAY_TRACING_DISPLACEMENT_MICROMAP_NV: PipelineCreateFlags2
pub const DESCRIPTOR_BUFFER_EXT: PipelineCreateFlags2
pub const PROTECTED_ACCESS_ONLY: PipelineCreateFlags2
pub const CAPTURE_DATA_KHR: PipelineCreateFlags2
pub const EXECUTION_GRAPH_AMDX: PipelineCreateFlags2
pub const RAY_TRACING_ALLOW_SPHERES_AND_LINEAR_SWEPT_SPHERES_NV: PipelineCreateFlags2
pub const ENABLE_LEGACY_DITHERING_EXT: PipelineCreateFlags2
pub const DESCRIPTOR_HEAP_EXT: PipelineCreateFlags2
pub const DISALLOW_OPACITY_MICROMAP_ARM: PipelineCreateFlags2
pub const INDIRECT_BINDABLE_EXT: PipelineCreateFlags2
pub const PER_LAYER_FRAGMENT_DENSITY_VALVE: PipelineCreateFlags2
pub const _64_BIT_INDEXING_EXT: PipelineCreateFlags2
Sourcepub const fn empty() -> PipelineCreateFlags2
pub const fn empty() -> PipelineCreateFlags2
Returns an empty set of flags.
Sourcepub const fn all() -> PipelineCreateFlags2
pub const fn all() -> PipelineCreateFlags2
Returns the set containing all flags.
Sourcepub const fn from_bits(bits: u64) -> Option<PipelineCreateFlags2>
pub const fn from_bits(bits: u64) -> Option<PipelineCreateFlags2>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: u64) -> PipelineCreateFlags2
pub const fn from_bits_truncate(bits: u64) -> PipelineCreateFlags2
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: u64) -> PipelineCreateFlags2
pub const unsafe fn from_bits_unchecked(bits: u64) -> PipelineCreateFlags2
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
Sourcepub const fn intersects(&self, other: PipelineCreateFlags2) -> bool
pub const fn intersects(&self, other: PipelineCreateFlags2) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: PipelineCreateFlags2) -> bool
pub const fn contains(&self, other: PipelineCreateFlags2) -> bool
Returns true if all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: PipelineCreateFlags2)
pub fn insert(&mut self, other: PipelineCreateFlags2)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: PipelineCreateFlags2)
pub fn remove(&mut self, other: PipelineCreateFlags2)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: PipelineCreateFlags2)
pub fn toggle(&mut self, other: PipelineCreateFlags2)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: PipelineCreateFlags2, value: bool)
pub fn set(&mut self, other: PipelineCreateFlags2, value: bool)
Inserts or removes the specified flags depending on the passed value.
Sourcepub const fn intersection(
self,
other: PipelineCreateFlags2,
) -> PipelineCreateFlags2
pub const fn intersection( self, other: PipelineCreateFlags2, ) -> PipelineCreateFlags2
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
Sourcepub const fn union(self, other: PipelineCreateFlags2) -> PipelineCreateFlags2
pub const fn union(self, other: PipelineCreateFlags2) -> PipelineCreateFlags2
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
Sourcepub const fn difference(
self,
other: PipelineCreateFlags2,
) -> PipelineCreateFlags2
pub const fn difference( self, other: PipelineCreateFlags2, ) -> PipelineCreateFlags2
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
Sourcepub const fn symmetric_difference(
self,
other: PipelineCreateFlags2,
) -> PipelineCreateFlags2
pub const fn symmetric_difference( self, other: PipelineCreateFlags2, ) -> PipelineCreateFlags2
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
Sourcepub const fn complement(self) -> PipelineCreateFlags2
pub const fn complement(self) -> PipelineCreateFlags2
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.