#[repr(C)]pub struct QueryPoolPerformanceQueryCreateInfoINTEL {
pub s_type: StructureType,
pub next: *const c_void,
pub performance_counters_sampling: QueryPoolSamplingModeINTEL,
}Expand description
Fields
s_type: StructureTypenext: *const c_voidperformance_counters_sampling: QueryPoolSamplingModeINTELTrait Implementations
Sourceimpl Cast for QueryPoolPerformanceQueryCreateInfoINTEL
impl Cast for QueryPoolPerformanceQueryCreateInfoINTEL
Sourcetype Target = QueryPoolPerformanceQueryCreateInfoINTEL
type Target = QueryPoolPerformanceQueryCreateInfoINTEL
The other type this type can be used interchangeably with in FFI.
Sourceimpl Clone for QueryPoolPerformanceQueryCreateInfoINTEL
impl Clone for QueryPoolPerformanceQueryCreateInfoINTEL
Sourcefn clone(&self) -> QueryPoolPerformanceQueryCreateInfoINTEL
fn clone(&self) -> QueryPoolPerformanceQueryCreateInfoINTEL
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for QueryPoolPerformanceQueryCreateInfoINTEL
impl Default for QueryPoolPerformanceQueryCreateInfoINTEL
Sourcefn default() -> QueryPoolPerformanceQueryCreateInfoINTEL
fn default() -> QueryPoolPerformanceQueryCreateInfoINTEL
Returns the “default value” for a type. Read more
Sourceimpl HasBuilder<'static> for QueryPoolPerformanceQueryCreateInfoINTEL
impl HasBuilder<'static> for QueryPoolPerformanceQueryCreateInfoINTEL
Sourceimpl InputChainStruct for QueryPoolPerformanceQueryCreateInfoINTEL
impl InputChainStruct for QueryPoolPerformanceQueryCreateInfoINTEL
Sourceconst TYPE: StructureType = StructureType::QUERY_POOL_PERFORMANCE_QUERY_CREATE_INFO_INTEL
const TYPE: StructureType = StructureType::QUERY_POOL_PERFORMANCE_QUERY_CREATE_INFO_INTEL
The structure type for this struct type.
Sourcefn s_type(&self) -> StructureType
fn s_type(&self) -> StructureType
The structure type for this struct.
Sourceimpl PartialEq for QueryPoolPerformanceQueryCreateInfoINTEL
impl PartialEq for QueryPoolPerformanceQueryCreateInfoINTEL
Sourcefn eq(&self, other: &QueryPoolPerformanceQueryCreateInfoINTEL) -> bool
fn eq(&self, other: &QueryPoolPerformanceQueryCreateInfoINTEL) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for QueryPoolPerformanceQueryCreateInfoINTEL
impl Eq for QueryPoolPerformanceQueryCreateInfoINTEL
impl ExtendsQueryPoolCreateInfo for QueryPoolPerformanceQueryCreateInfoINTEL
impl Send for QueryPoolPerformanceQueryCreateInfoINTEL
impl StructuralPartialEq for QueryPoolPerformanceQueryCreateInfoINTEL
impl Sync for QueryPoolPerformanceQueryCreateInfoINTEL