#[repr(C)]pub struct VideoEncodeProfileRgbConversionInfoVALVE {
pub s_type: StructureType,
pub next: *const c_void,
pub perform_encode_rgb_conversion: u32,
}Expand description
Fields
s_type: StructureTypenext: *const c_voidperform_encode_rgb_conversion: u32Trait Implementations
Sourceimpl Cast for VideoEncodeProfileRgbConversionInfoVALVE
impl Cast for VideoEncodeProfileRgbConversionInfoVALVE
Sourcetype Target = VideoEncodeProfileRgbConversionInfoVALVE
type Target = VideoEncodeProfileRgbConversionInfoVALVE
The other type this type can be used interchangeably with in FFI.
Sourceimpl Clone for VideoEncodeProfileRgbConversionInfoVALVE
impl Clone for VideoEncodeProfileRgbConversionInfoVALVE
Sourcefn clone(&self) -> VideoEncodeProfileRgbConversionInfoVALVE
fn clone(&self) -> VideoEncodeProfileRgbConversionInfoVALVE
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for VideoEncodeProfileRgbConversionInfoVALVE
impl Default for VideoEncodeProfileRgbConversionInfoVALVE
Sourcefn default() -> VideoEncodeProfileRgbConversionInfoVALVE
fn default() -> VideoEncodeProfileRgbConversionInfoVALVE
Returns the “default value” for a type. Read more
Sourceimpl HasBuilder<'static> for VideoEncodeProfileRgbConversionInfoVALVE
impl HasBuilder<'static> for VideoEncodeProfileRgbConversionInfoVALVE
Sourceimpl InputChainStruct for VideoEncodeProfileRgbConversionInfoVALVE
impl InputChainStruct for VideoEncodeProfileRgbConversionInfoVALVE
Sourceconst TYPE: StructureType = StructureType::VIDEO_ENCODE_PROFILE_RGB_CONVERSION_INFO_VALVE
const TYPE: StructureType = StructureType::VIDEO_ENCODE_PROFILE_RGB_CONVERSION_INFO_VALVE
The structure type for this struct type.
Sourcefn s_type(&self) -> StructureType
fn s_type(&self) -> StructureType
The structure type for this struct.
Sourceimpl PartialEq for VideoEncodeProfileRgbConversionInfoVALVE
impl PartialEq for VideoEncodeProfileRgbConversionInfoVALVE
Sourcefn eq(&self, other: &VideoEncodeProfileRgbConversionInfoVALVE) -> bool
fn eq(&self, other: &VideoEncodeProfileRgbConversionInfoVALVE) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for VideoEncodeProfileRgbConversionInfoVALVE
impl Eq for VideoEncodeProfileRgbConversionInfoVALVE
impl ExtendsVideoProfileInfoKHR for VideoEncodeProfileRgbConversionInfoVALVE
impl Send for VideoEncodeProfileRgbConversionInfoVALVE
impl StructuralPartialEq for VideoEncodeProfileRgbConversionInfoVALVE
impl Sync for VideoEncodeProfileRgbConversionInfoVALVE