#[repr(C)]pub struct VideoEncodeRgbConversionCapabilitiesVALVE {
pub s_type: StructureType,
pub next: *mut c_void,
pub rgb_models: VideoEncodeRgbModelConversionFlagsVALVE,
pub rgb_ranges: VideoEncodeRgbRangeCompressionFlagsVALVE,
pub x_chroma_offsets: VideoEncodeRgbChromaOffsetFlagsVALVE,
pub y_chroma_offsets: VideoEncodeRgbChromaOffsetFlagsVALVE,
}Expand description
Fields
s_type: StructureTypenext: *mut c_voidrgb_models: VideoEncodeRgbModelConversionFlagsVALVErgb_ranges: VideoEncodeRgbRangeCompressionFlagsVALVEx_chroma_offsets: VideoEncodeRgbChromaOffsetFlagsVALVEy_chroma_offsets: VideoEncodeRgbChromaOffsetFlagsVALVETrait Implementations
Sourceimpl Cast for VideoEncodeRgbConversionCapabilitiesVALVE
impl Cast for VideoEncodeRgbConversionCapabilitiesVALVE
Sourcetype Target = VideoEncodeRgbConversionCapabilitiesVALVE
type Target = VideoEncodeRgbConversionCapabilitiesVALVE
The other type this type can be used interchangeably with in FFI.
Sourceimpl Clone for VideoEncodeRgbConversionCapabilitiesVALVE
impl Clone for VideoEncodeRgbConversionCapabilitiesVALVE
Sourcefn clone(&self) -> VideoEncodeRgbConversionCapabilitiesVALVE
fn clone(&self) -> VideoEncodeRgbConversionCapabilitiesVALVE
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for VideoEncodeRgbConversionCapabilitiesVALVE
impl Default for VideoEncodeRgbConversionCapabilitiesVALVE
Sourcefn default() -> VideoEncodeRgbConversionCapabilitiesVALVE
fn default() -> VideoEncodeRgbConversionCapabilitiesVALVE
Returns the “default value” for a type. Read more
Sourceimpl HasBuilder<'static> for VideoEncodeRgbConversionCapabilitiesVALVE
impl HasBuilder<'static> for VideoEncodeRgbConversionCapabilitiesVALVE
Sourceimpl InputChainStruct for VideoEncodeRgbConversionCapabilitiesVALVE
impl InputChainStruct for VideoEncodeRgbConversionCapabilitiesVALVE
Sourceconst TYPE: StructureType = StructureType::VIDEO_ENCODE_RGB_CONVERSION_CAPABILITIES_VALVE
const TYPE: StructureType = StructureType::VIDEO_ENCODE_RGB_CONVERSION_CAPABILITIES_VALVE
The structure type for this struct type.
Sourcefn s_type(&self) -> StructureType
fn s_type(&self) -> StructureType
The structure type for this struct.
Sourceimpl PartialEq for VideoEncodeRgbConversionCapabilitiesVALVE
impl PartialEq for VideoEncodeRgbConversionCapabilitiesVALVE
Sourcefn eq(&self, other: &VideoEncodeRgbConversionCapabilitiesVALVE) -> bool
fn eq(&self, other: &VideoEncodeRgbConversionCapabilitiesVALVE) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for VideoEncodeRgbConversionCapabilitiesVALVE
impl Eq for VideoEncodeRgbConversionCapabilitiesVALVE
impl ExtendsVideoCapabilitiesKHR for VideoEncodeRgbConversionCapabilitiesVALVE
impl Send for VideoEncodeRgbConversionCapabilitiesVALVE
impl StructuralPartialEq for VideoEncodeRgbConversionCapabilitiesVALVE
impl Sync for VideoEncodeRgbConversionCapabilitiesVALVE