#[repr(C)]pub struct VideoEncodeSessionRgbConversionCreateInfoVALVE {
pub s_type: StructureType,
pub next: *const c_void,
pub rgb_model: VideoEncodeRgbModelConversionFlagsVALVE,
pub rgb_range: VideoEncodeRgbRangeCompressionFlagsVALVE,
pub x_chroma_offset: VideoEncodeRgbChromaOffsetFlagsVALVE,
pub y_chroma_offset: VideoEncodeRgbChromaOffsetFlagsVALVE,
}Expand description
Fields
s_type: StructureTypenext: *const c_voidrgb_model: VideoEncodeRgbModelConversionFlagsVALVErgb_range: VideoEncodeRgbRangeCompressionFlagsVALVEx_chroma_offset: VideoEncodeRgbChromaOffsetFlagsVALVEy_chroma_offset: VideoEncodeRgbChromaOffsetFlagsVALVETrait Implementations
Sourceimpl Cast for VideoEncodeSessionRgbConversionCreateInfoVALVE
impl Cast for VideoEncodeSessionRgbConversionCreateInfoVALVE
Sourcetype Target = VideoEncodeSessionRgbConversionCreateInfoVALVE
type Target = VideoEncodeSessionRgbConversionCreateInfoVALVE
The other type this type can be used interchangeably with in FFI.
Sourceimpl Clone for VideoEncodeSessionRgbConversionCreateInfoVALVE
impl Clone for VideoEncodeSessionRgbConversionCreateInfoVALVE
Sourcefn clone(&self) -> VideoEncodeSessionRgbConversionCreateInfoVALVE
fn clone(&self) -> VideoEncodeSessionRgbConversionCreateInfoVALVE
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for VideoEncodeSessionRgbConversionCreateInfoVALVE
impl Default for VideoEncodeSessionRgbConversionCreateInfoVALVE
Sourcefn default() -> VideoEncodeSessionRgbConversionCreateInfoVALVE
fn default() -> VideoEncodeSessionRgbConversionCreateInfoVALVE
Returns the “default value” for a type. Read more
Sourceimpl HasBuilder<'static> for VideoEncodeSessionRgbConversionCreateInfoVALVE
impl HasBuilder<'static> for VideoEncodeSessionRgbConversionCreateInfoVALVE
Sourceimpl InputChainStruct for VideoEncodeSessionRgbConversionCreateInfoVALVE
impl InputChainStruct for VideoEncodeSessionRgbConversionCreateInfoVALVE
Sourceconst TYPE: StructureType = StructureType::VIDEO_ENCODE_SESSION_RGB_CONVERSION_CREATE_INFO_VALVE
const TYPE: StructureType = StructureType::VIDEO_ENCODE_SESSION_RGB_CONVERSION_CREATE_INFO_VALVE
The structure type for this struct type.
Sourcefn s_type(&self) -> StructureType
fn s_type(&self) -> StructureType
The structure type for this struct.
Sourceimpl PartialEq for VideoEncodeSessionRgbConversionCreateInfoVALVE
impl PartialEq for VideoEncodeSessionRgbConversionCreateInfoVALVE
Sourcefn eq(&self, other: &VideoEncodeSessionRgbConversionCreateInfoVALVE) -> bool
fn eq(&self, other: &VideoEncodeSessionRgbConversionCreateInfoVALVE) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for VideoEncodeSessionRgbConversionCreateInfoVALVE
impl Eq for VideoEncodeSessionRgbConversionCreateInfoVALVE
impl ExtendsVideoSessionCreateInfoKHR for VideoEncodeSessionRgbConversionCreateInfoVALVE
impl Send for VideoEncodeSessionRgbConversionCreateInfoVALVE
impl StructuralPartialEq for VideoEncodeSessionRgbConversionCreateInfoVALVE
impl Sync for VideoEncodeSessionRgbConversionCreateInfoVALVE