pub unsafe trait ExtendsCommandBufferBeginInfo: Debug { }Expand description
A Vulkan struct that can be used to extend a CommandBufferBeginInfo.
pub unsafe trait ExtendsCommandBufferBeginInfo: Debug { }A Vulkan struct that can be used to extend a CommandBufferBeginInfo.