pub unsafe trait ExtendsDeviceCreateInfo: Debug { }Expand description
A Vulkan struct that can be used to extend a DeviceCreateInfo.
pub unsafe trait ExtendsDeviceCreateInfo: Debug { }A Vulkan struct that can be used to extend a DeviceCreateInfo.