pub unsafe trait ExtendsVideoCodingControlInfoKHR: Debug { }Expand description
A Vulkan struct that can be used to extend a VideoCodingControlInfoKHR.
pub unsafe trait ExtendsVideoCodingControlInfoKHR: Debug { }A Vulkan struct that can be used to extend a VideoCodingControlInfoKHR.